.. _examples-implants:

Implants
========

The :py:mod:`~pulse2percept.implants` module provides access to various
state-of-the-art retinal prostheses, such as
:py:class:`~pulse2percept.implants.ArgusI` and
:py:class:`~pulse2percept.implants.ArgusII` (epiretinal),
:py:class:`~pulse2percept.implants.Alpha-IMS` and
:py:class:`~pulse2percept.implants.PRIMA` (subretinal),
as well as :py:class:`~pulse2percept.implants.BVT24` (suprachoroidal).

Other implants can be added by creating a new 
:py:class:`~pulse2percept.implants.ProsthesisSystem` object.
